@@ -52,7 +52,8 @@ def colored(text, color="blue"):
 COMPANY_NAME = "mobilize.net"
 
 # global status values
-max_errors = 1
+_max_error_level = -1
+max_errors = -1
 current_error_count = 0
 activity_count = 0
 error_code = 0
@@ -96,7 +97,7 @@ def log(*msg, level=logging.INFO, writter=None):
             The message to print or log.
     """
     if snow_logging_enabled :
-        finalmsg = [re.sub('\033\[\d*m','', str(item)) for item in msg]
+        finalmsg = [re.sub(r'\033\[\d*m','', str(item)) for item in msg]
         if level == logging.ERROR :
             logging.error(*finalmsg)
         elif level == logging.DEBUG:
@@ -374,7 +375,8 @@ def exec(sql_string, using=None, con=None):
     global opened_connections
     global activity_count
     global current_error_count
-    global max_errors
+    global _max_error_level
+    global error_level
     global error_code
     global _previous_executed_sql
     if (con is None):
@@ -412,8 +414,11 @@ def exec(sql_string, using=None, con=None):
     finally:
         _previous_executed_sql = sql_string
         cur.close()
-        if current_error_count >= max_errors:
-            log(colored(f'*** Failure: reached max error count {max_errors}', 'red'), level = logging.ERROR)
+        if _max_error_level >= 0 and _max_error_level <= error_level:
+            log(colored(f'*** Failure: reached max error level {error_level}', 'red'), level = logging.ERROR)
+            quit_application(1)
+        elif max_errors > 0 and current_error_count >= max_errors:
+            log(colored(f'*** Failure: reached max number of errors  {max_errors}', 'red'), level = logging.ERROR)
             quit_application(1)
 
 def repeat_previous_sql_statement(con=None, n=1):
@@ -500,6 +505,10 @@ def set_default_error_level(severity_value):
     global _default_error_level
     _default_error_level = severity_value
 
+def set_max_error_level(severity_value):
+    global _max_error_level
+    _max_error_level = severity_value
+
 def os(args):
     global system_return_code
     system_return_code = system(args)
@@ -576,11 +585,13 @@ def quit_application(code=None):
         return
     quit_application_already_called = True
     code = code or error_level
-    log(colored(f"Error Code {code}", 'red'), level = logging.ERROR, writter = sys.stderr)
     if code != 0:
+        log(colored(f"Exit code: {code}", 'red'), level = logging.ERROR, writter = sys.stderr)
         stack_trace = get_error_position()
         log(colored(stack_trace, 'red'), level = logging.ERROR, writter = sys.stderr)
-    sys.exit(code)
+        sys.exit(code)
+    else:
+        log(colored(f"Exit code: {code}", 'red'), level = logging.INFO, writter = sys.stdout)
 
 def import_file_to_temptable(filename, tempTableName, columnDefinition):
     """Imports the file passed to a temporary table.
